@@ -33,10 +33,10 @@ available_domain_types = ["points", "image", "audio"]
 class BaseProject:
     r"""Parent class of `Project` class. 
     
-    Methods will perform 1)plotting data, 2)generating ``Experiment``s,
-    3)setting models across the generated `Experiment`s, 4)setting trainers across the generated ``Experiment``s,
+    Methods will perform 1)plotting data, 2)generating ``Experiments``,
+    3)setting models across the generated `Experiment`s, 4)setting trainers across the generated ``Experiments``,
     5)training models across the generated `Experiment`s, 6)updating project metadata,
-    7)adding individual ``Experiment`` to the project, 8)saving checkpoints for ``Experiment``s saved in ``exps``,
+    7)adding individual ``Experiment`` to the project, 8)saving checkpoints for ``Experiments`` saved in ``exps``,
     9)saving stacks for each ``Experiment`` in ``exps``, 9)flushing all ``exps``. 
 
     Attributes:
@@ -71,7 +71,7 @@ class BaseProject:
 
         birthday (str): Time when the project is created.
 
-        exps (:obj:`dict` of :obj:`str`, :obj:`Experiment`): `Project` can control ``Experiment``s in ``exps``.
+        exps (:obj:`dict` of :obj:`str`, :obj:`Experiment`): `Project` can control ``Experiments`` in ``exps``.
         
         n_exps (int): Number of ``Experiemnt``s in ``exps``.
 
@@ -169,20 +169,20 @@ class BaseProject:
         stack_models : bool = True,
         stack_exps : bool = True
     )->Dict[str, "Experiment"]: # {name of the experiment} : Experiment
-        r"""Generates ``Experiment``s and stack them to ``exps`` if needed.
+        r"""Generates ``Experiments`` and stack them to ``exps`` if needed.
 
         Args:
             
-            amount (int) : The number of ``Experiment``s you want to generate.
+            amount (int) : The number of ``Experiments`` you want to generate.
                 Default: ``10``
             
-            test_size (float) : Test size when splitting the data. Neccessary for creating ``Experiment``s.
+            test_size (float) : Test size when splitting the data. Neccessary for creating ``Experiments``.
                 Default: ``1e-2``
             
             stack_models (bool) : Whehter to stack models in each ``Experiment`` or not.
                 Default: ``True``
             
-            stack_exps (bool) : Whether to stack generated ``Experiment``s to ``exps`` or not.
+            stack_exps (bool) : Whether to stack generated ``Experiments`` to ``exps`` or not.
                 Default: ``True``
         
         Returns:
@@ -256,7 +256,7 @@ class BaseProject:
         random_states : Optional[List[int]] = None, # if None, same models are set for all experiments created in the Project
         **hparams
     )->None:
-        r"""Set identical models across ``Experiment``s.
+        r"""Set identical models across ``Experiments``.
 
         Args:
 
@@ -264,7 +264,7 @@ class BaseProject:
 
             **hparams (Any): Hyperparameters for the model. 
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiment``s you want to set model to. If None, will set models for all ``Experiment``s in ``exps``.
+            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to set model to. If None, will set models for all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
@@ -292,13 +292,13 @@ class BaseProject:
         random_states : Optional[List[int]] = None, # if None, same trainers are set for all experiments created in the Project
         **trainer_config
     )->None:
-        r"""Set identical trainers across ``Experiment``s.
+        r"""Set identical trainers across ``Experiments``.
 
         Args:
 
             **trainer_config (Any): Trainer configurations.
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiment``s you want to set trainer to. If None, will set trainers for all ``Experiment``s in ``exps``.
+            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to set trainer to. If None, will set trainers for all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
@@ -326,13 +326,13 @@ class BaseProject:
         random_states : Optional[List[int]] = None, # if None, all experiments will be fitted,
         **trainer_config
     )->None:
-        r"""Fit models in ``Experiment``s stacked in ``exps``.
+        r"""Fit models in ``Experiments`` stacked in ``exps``.
 
         Args:
 
             **trainer_config (Any): Trainer configurations.
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiment``s you want to fit. If None, will fit all ``Experiment``s in ``exps``.
+            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to fit. If None, will fit all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
@@ -359,11 +359,11 @@ class BaseProject:
         self,
         random_states : Optional[List[int]] = None, # if None, all experiments will save checkpoints
     )->None:
-        r"""Save checkpoints in ``Experiment``s stacked in ``exps``.
+        r"""Save checkpoints in ``Experiments`` stacked in ``exps``.
 
         Args:
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiment``s you want to save checkpoint. If None, will save checkpoint for all ``Experiment``s in ``exps``.
+            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to save checkpoint. If None, will save checkpoint for all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
@@ -389,11 +389,11 @@ class BaseProject:
         self,
         random_states : Optional[List[int]] = None, # if None, all experiments will save stacks
     )->None:
-        r"""Apply `save_stack` for ``Experiment``s in ``exps``.
+        r"""Apply `save_stack` for ``Experiments`` in ``exps``.
 
         Args:
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiment``s you want to save stack. If None, will save stack for all ``Experiment``s in ``exps``.
+            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to save stack. If None, will save stack for all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
@@ -418,7 +418,7 @@ class BaseProject:
     def save_project(
         self
     )->None:
-        r"""Save all ``Experiment``s.
+        r"""Save all ``Experiments``.
         """
         if self.exps:
             self.save_stacks()
@@ -620,11 +620,11 @@ class BaseProject:
     def get_available_random_states(
         self
     )->List[str]:
-        r"""Returns list of directories of ``Experiment``s that has been fitted and logged.
+        r"""Returns list of directories of ``Experiments`` that has been fitted and logged.
 
         Returns:
 
-            list of `str`: All directories of fitted and logged ``Experiment``s.
+            list of `str`: All directories of fitted and logged ``Experiments``.
         """
         log_base_dir = self.project_path + "/FIT"
         random_state_dir_list = []
@@ -636,7 +636,7 @@ class BaseProject:
     def search_standard(
         self,
         val_metric : str = 'val/acc'
-    )-> tuple["np.ndarray", dict[str,int], dict[str,int]]: 
+    )->tuple["np.ndarray", dict[str,int], dict[str,int]]: 
         r"""Search method for finding the model type/structure with best validation performance.
 
         Args:
@@ -646,7 +646,7 @@ class BaseProject:
 
         Returns:
 
-            tuple: (numpy ndarray of validation performances across ``Experiment``s, dictionary of {model type:it's frequency}, dictionary of {model structure:it's frequency}).
+            tuple: (numpy ndarray of validation performances across ``Experiments``, dictionary of {model type:it's frequency}, dictionary of {model structure:it's frequency}).
 
         """ 
         performances = []
@@ -873,7 +873,7 @@ class BaseProject:
         return (metadata_list, performances_list)
 
     @staticmethod
-    def _create_folder(directory : str) -> str: #path of directory
+    def _create_folder(directory : str)->str: #path of directory
         r"""Creates folder.
         
         Args:
@@ -925,7 +925,7 @@ class Project(BaseProject):
 
         birthday (str): Time when the project is created.
 
-        exps (:obj:`dict` of :obj:`str`, :obj:`Experiment`): `Project` can control ``Experiment``s in ``exps``.
+        exps (:obj:`dict` of :obj:`str`, :obj:`Experiment`): `Project` can control ``Experiments`` in ``exps``.
         
         n_exps (int): Number of ``Experiemnt``s in ``exps``.
 
@@ -977,7 +977,7 @@ class Project(BaseProject):
             path=path
         )
 
-    def plot_best_models(
+    def plot_best_performances(
             self,
             val_metric : str = 'val/acc',
             plt_title : Optional[str] = None
@@ -1028,7 +1028,7 @@ class Project(BaseProject):
 
             return (performances, info)
 
-    def plot_characteristics(
+    def plot_best_model_frequencies(
         self,
         val_metric : str = 'val/acc',
         plt_title : Optional[str] = None
@@ -1100,7 +1100,7 @@ class Project(BaseProject):
 
         Returns:
 
-            tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiment``s, dictionary containing information of the search)
+            tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiments``, dictionary containing information of the search)
         """
         performances, best_model_structures = self.search_with_model_type(val_metric=val_metric, model_type=model_type)
         random_state_dir_list = self.get_available_random_states()
@@ -1155,7 +1155,7 @@ class Project(BaseProject):
 
         Returns:
 
-            tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiment``s)
+            tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiments``)
         """
         performances, metadata = self.search_with_model_type_hparams(
             val_metric=val_metric, model_type=model_type, **hparams
@@ -1193,8 +1193,8 @@ class Project(BaseProject):
     
     @staticmethod
     def generate_marker_style(amount)->List[str]: 
-        # string specifying the marker style
-
+        r"""Returns a string specifying the marker style
+        """
         color_list = ['b','g','r','c','m','y','k','w']
         shape_list = [".", "v", "1", "*", "^", "s", "<"]
         random.shuffle(color_list)
@@ -1206,12 +1206,14 @@ class Project(BaseProject):
                 break
         return marker_styles
 
-    def plot_all_models(
+    def plot_all_model_structures(
         self,
         val_metric : str = "val/acc",
         plt_title : Optional[str] = None
     )->tuple["np.ndarray", List[str]]:
-        r"""Plots validation performances across different random states for all model structures saved. Will plot 1)line graphs and 2)box plots.
+        r"""Plots validation performances across different random states for all model structures saved. 
+        
+        Will plot 1)line graphs and 2)box plots.
 
         Args:
 
@@ -1223,7 +1225,7 @@ class Project(BaseProject):
 
         Returns:
 
-            tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiment``s)
+            tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiments``)
         """
     # (validation performances, list of model metadata)
         
